==> apache-camel-3.4.6-src.zip: apache-camel-3.4.6/components/camel-hazelcast/src/main/java/org/apache/camel/component/hazelcast/list/HazelcastListConsumer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.hazelcast.list;

import com.hazelcast.collection.IList;
import com.hazelcast.core.HazelcastInstance;
import org.apache.camel.Consumer;
import org.apache.camel.Endpoint;
import org.apache.camel.Processor;
import org.apache.camel.component.hazelcast.HazelcastDefaultConsumer;
import org.apache.camel.component.hazelcast.listener.CamelItemListener;

/**
 * Implementation of Hazelcast List {@link Consumer}.
 */
public class HazelcastListConsumer extends HazelcastDefaultConsumer {

    public HazelcastListConsumer(HazelcastInstance hazelcastInstance, Endpoint endpoint, Processor processor, String cacheName) {
        super(hazelcastInstance, endpoint, processor, cacheName);

        IList<Object> queue = hazelcastInstance.getList(cacheName);
        queue.addItemListener(new CamelItemListener(this, cacheName), true);
    }

}

==> apache-camel-3.7.6-src.zip: apache-camel-3.7.6/components/camel-hazelcast/src/main/java/org/apache/camel/component/hazelcast/list/HazelcastListConsumer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.hazelcast.list;

import java.util.UUID;

import com.hazelcast.collection.IList;
import com.hazelcast.core.HazelcastInstance;
import org.apache.camel.Consumer;
import org.apache.camel.Endpoint;
import org.apache.camel.Processor;
import org.apache.camel.component.hazelcast.HazelcastDefaultConsumer;
import org.apache.camel.component.hazelcast.listener.CamelItemListener;

/**
 * Implementation of Hazelcast List {@link Consumer}.
 */
public class HazelcastListConsumer extends HazelcastDefaultConsumer {

    private final IList<Object> queue;

    private UUID listener;

    public HazelcastListConsumer(HazelcastInstance hazelcastInstance, Endpoint endpoint, Processor processor,
                                 String cacheName) {
        super(hazelcastInstance, endpoint, processor, cacheName);

        queue = hazelcastInstance.getList(cacheName);
    }

    /**
     * @see org.apache.camel.support.DefaultConsumer#doStart()
     */
    @Override
    protected void doStart() throws Exception {
        super.doStart();

        listener = queue.addItemListener(new CamelItemListener(this, cacheName), true);
    }

    /**
     * @see org.apache.camel.support.DefaultConsumer#doStop()
     */
    @Override
    protected void doStop() throws Exception {
        queue.removeItemListener(listener);

        super.doStop();
    }

}
